==> org-lsst-sal-camera-2.2.1-sources.jar: org/lsst/sal/camera/telemetry/Quadbox_REB_Bulk_PSTelemetry.java <==
package org.lsst.sal.camera.telemetry;

import org.lsst.sal.camera.CameraTelemetry;

public class Quadbox_REB_Bulk_PSTelemetry extends CameraTelemetry {
  private final double rebbulkps_Brd_T;

  private final double rebbulkps_0_2_V;

  private final double rebbulkps_0_2_I;

  private final double rebbulkps_0_2_T;

  private final double rebbulkps_3_5_V;

  private final double rebbulkps_3_5_I;

  private final double rebbulkps_3_5_T;

  private final double rebbulkps_6_8_V;

  private final double rebbulkps_6_8_I;

  private final double rebbulkps_6_8_T;

  private final double rebbulkps_9_12_V;

  private final double rebbulkps_9_12_I;

  private final double rebbulkps_9_12_T;

  public Quadbox_REB_Bulk_PSTelemetry(double rebbulkps_Brd_T, double rebbulkps_0_2_V,
      double rebbulkps_0_2_I, double rebbulkps_0_2_T, double rebbulkps_3_5_V,
      double rebbulkps_3_5_I, double rebbulkps_3_5_T, double rebbulkps_6_8_V,
      double rebbulkps_6_8_I, double rebbulkps_6_8_T, double rebbulkps_9_12_V,
      double rebbulkps_9_12_I, double rebbulkps_9_12_T) {
    this.rebbulkps_Brd_T = rebbulkps_Brd_T;
    this.rebbulkps_0_2_V = rebbulkps_0_2_V;
    this.rebbulkps_0_2_I = rebbulkps_0_2_I;
    this.rebbulkps_0_2_T = rebbulkps_0_2_T;
    this.rebbulkps_3_5_V = rebbulkps_3_5_V;
    this.rebbulkps_3_5_I = rebbulkps_3_5_I;
    this.rebbulkps_3_5_T = rebbulkps_3_5_T;
    this.rebbulkps_6_8_V = rebbulkps_6_8_V;
    this.rebbulkps_6_8_I = rebbulkps_6_8_I;
    this.rebbulkps_6_8_T = rebbulkps_6_8_T;
    this.rebbulkps_9_12_V = rebbulkps_9_12_V;
    this.rebbulkps_9_12_I = rebbulkps_9_12_I;
    this.rebbulkps_9_12_T = rebbulkps_9_12_T;
  }

  public double getRebbulkps_Brd_T() {
    return rebbulkps_Brd_T;
  }

  public double getRebbulkps_0_2_V() {
    return rebbulkps_0_2_V;
  }

  public double getRebbulkps_0_2_I() {
    return rebbulkps_0_2_I;
  }

  public double getRebbulkps_0_2_T() {
    return rebbulkps_0_2_T;
  }

  public double getRebbulkps_3_5_V() {
    return rebbulkps_3_5_V;
  }

  public double getRebbulkps_3_5_I() {
    return rebbulkps_3_5_I;
  }

  public double getRebbulkps_3_5_T() {
    return rebbulkps_3_5_T;
  }

  public double getRebbulkps_6_8_V() {
    return rebbulkps_6_8_V;
  }

  public double getRebbulkps_6_8_I() {
    return rebbulkps_6_8_I;
  }

  public double getRebbulkps_6_8_T() {
    return rebbulkps_6_8_T;
  }

  public double getRebbulkps_9_12_V() {
    return rebbulkps_9_12_V;
  }

  public double getRebbulkps_9_12_I() {
    return rebbulkps_9_12_I;
  }

  public double getRebbulkps_9_12_T() {
    return rebbulkps_9_12_T;
  }

  @Override
  public String toString() {
    return "Quadbox_REB_Bulk_PSTelemetry{" + "rebbulkps_Brd_T=" + rebbulkps_Brd_T +
        ", rebbulkps_0_2_V=" + rebbulkps_0_2_V +", rebbulkps_0_2_I=" + rebbulkps_0_2_I +
        ", rebbulkps_0_2_T=" + rebbulkps_0_2_T +", rebbulkps_3_5_V=" + rebbulkps_3_5_V +
        ", rebbulkps_3_5_I=" + rebbulkps_3_5_I +", rebbulkps_3_5_T=" + rebbulkps_3_5_T +
        ", rebbulkps_6_8_V=" + rebbulkps_6_8_V +", rebbulkps_6_8_I=" + rebbulkps_6_8_I +
        ", rebbulkps_6_8_T=" + rebbulkps_6_8_T +", rebbulkps_9_12_V=" + rebbulkps_9_12_V +
        ", rebbulkps_9_12_I=" + rebbulkps_9_12_I +", rebbulkps_9_12_T=" + rebbulkps_9_12_T +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private double rebbulkps_Brd_T;

    private double rebbulkps_0_2_V;

    private double rebbulkps_0_2_I;

    private double rebbulkps_0_2_T;

    private double rebbulkps_3_5_V;

    private double rebbulkps_3_5_I;

    private double rebbulkps_3_5_T;

    private double rebbulkps_6_8_V;

    private double rebbulkps_6_8_I;

    private double rebbulkps_6_8_T;

    private double rebbulkps_9_12_V;

    private double rebbulkps_9_12_I;

    private double rebbulkps_9_12_T;

    private Builder() {
    }

    public Builder rebbulkps_Brd_T(double rebbulkps_Brd_T) {
      this.rebbulkps_Brd_T = rebbulkps_Brd_T;
      return this;
    }

    public Builder rebbulkps_0_2_V(double rebbulkps_0_2_V) {
      this.rebbulkps_0_2_V = rebbulkps_0_2_V;
      return this;
    }

    public Builder rebbulkps_0_2_I(double rebbulkps_0_2_I) {
      this.rebbulkps_0_2_I = rebbulkps_0_2_I;
      return this;
    }

    public Builder rebbulkps_0_2_T(double rebbulkps_0_2_T) {
      this.rebbulkps_0_2_T = rebbulkps_0_2_T;
      return this;
    }

    public Builder rebbulkps_3_5_V(double rebbulkps_3_5_V) {
      this.rebbulkps_3_5_V = rebbulkps_3_5_V;
      return this;
    }

    public Builder rebbulkps_3_5_I(double rebbulkps_3_5_I) {
      this.rebbulkps_3_5_I = rebbulkps_3_5_I;
      return this;
    }

    public Builder rebbulkps_3_5_T(double rebbulkps_3_5_T) {
      this.rebbulkps_3_5_T = rebbulkps_3_5_T;
      return this;
    }

    public Builder rebbulkps_6_8_V(double rebbulkps_6_8_V) {
      this.rebbulkps_6_8_V = rebbulkps_6_8_V;
      return this;
    }

    public Builder rebbulkps_6_8_I(double rebbulkps_6_8_I) {
      this.rebbulkps_6_8_I = rebbulkps_6_8_I;
      return this;
    }

    public Builder rebbulkps_6_8_T(double rebbulkps_6_8_T) {
      this.rebbulkps_6_8_T = rebbulkps_6_8_T;
      return this;
    }

    public Builder rebbulkps_9_12_V(double rebbulkps_9_12_V) {
      this.rebbulkps_9_12_V = rebbulkps_9_12_V;
      return this;
    }

    public Builder rebbulkps_9_12_I(double rebbulkps_9_12_I) {
      this.rebbulkps_9_12_I = rebbulkps_9_12_I;
      return this;
    }

    public Builder rebbulkps_9_12_T(double rebbulkps_9_12_T) {
      this.rebbulkps_9_12_T = rebbulkps_9_12_T;
      return this;
    }

    public Quadbox_REB_Bulk_PSTelemetry build() {
      return new Quadbox_REB_Bulk_PSTelemetry(rebbulkps_Brd_T, rebbulkps_0_2_V, rebbulkps_0_2_I, rebbulkps_0_2_T, rebbulkps_3_5_V, rebbulkps_3_5_I, rebbulkps_3_5_T, rebbulkps_6_8_V, rebbulkps_6_8_I, rebbulkps_6_8_T, rebbulkps_9_12_V, rebbulkps_9_12_I, rebbulkps_9_12_T);
    }
  }
}

==> org-lsst-sal-camera-3.0.0-sources.jar: org/lsst/sal/camera/telemetry/Quadbox_REB_Bulk_PSTelemetry.java <==
package org.lsst.sal.camera.telemetry;

import org.lsst.sal.camera.CameraTelemetry;

public class Quadbox_REB_Bulk_PSTelemetry extends CameraTelemetry {
  private final double rebbulkps_0_2_I;

  private final double rebbulkps_0_2_T;

  private final double rebbulkps_0_2_V;

  private final double rebbulkps_3_5_I;

  private final double rebbulkps_3_5_T;

  private final double rebbulkps_3_5_V;

  private final double rebbulkps_6_8_I;

  private final double rebbulkps_6_8_T;

  private final double rebbulkps_6_8_V;

  private final double rebbulkps_9_12_I;

  private final double rebbulkps_9_12_T;

  private final double rebbulkps_9_12_V;

  private final double rebbulkps_Brd_T;

  public Quadbox_REB_Bulk_PSTelemetry(double rebbulkps_0_2_I, double rebbulkps_0_2_T,
      double rebbulkps_0_2_V, double rebbulkps_3_5_I, double rebbulkps_3_5_T,
      double rebbulkps_3_5_V, double rebbulkps_6_8_I, double rebbulkps_6_8_T,
      double rebbulkps_6_8_V, double rebbulkps_9_12_I, double rebbulkps_9_12_T,
      double rebbulkps_9_12_V, double rebbulkps_Brd_T) {
    this.rebbulkps_0_2_I = rebbulkps_0_2_I;
    this.rebbulkps_0_2_T = rebbulkps_0_2_T;
    this.rebbulkps_0_2_V = rebbulkps_0_2_V;
    this.rebbulkps_3_5_I = rebbulkps_3_5_I;
    this.rebbulkps_3_5_T = rebbulkps_3_5_T;
    this.rebbulkps_3_5_V = rebbulkps_3_5_V;
    this.rebbulkps_6_8_I = rebbulkps_6_8_I;
    this.rebbulkps_6_8_T = rebbulkps_6_8_T;
    this.rebbulkps_6_8_V = rebbulkps_6_8_V;
    this.rebbulkps_9_12_I = rebbulkps_9_12_I;
    this.rebbulkps_9_12_T = rebbulkps_9_12_T;
    this.rebbulkps_9_12_V = rebbulkps_9_12_V;
    this.rebbulkps_Brd_T = rebbulkps_Brd_T;
  }

  public double getRebbulkps_0_2_I() {
    return rebbulkps_0_2_I;
  }

  public double getRebbulkps_0_2_T() {
    return rebbulkps_0_2_T;
  }

  public double getRebbulkps_0_2_V() {
    return rebbulkps_0_2_V;
  }

  public double getRebbulkps_3_5_I() {
    return rebbulkps_3_5_I;
  }

  public double getRebbulkps_3_5_T() {
    return rebbulkps_3_5_T;
  }

  public double getRebbulkps_3_5_V() {
    return rebbulkps_3_5_V;
  }

  public double getRebbulkps_6_8_I() {
    return rebbulkps_6_8_I;
  }

  public double getRebbulkps_6_8_T() {
    return rebbulkps_6_8_T;
  }

  public double getRebbulkps_6_8_V() {
    return rebbulkps_6_8_V;
  }

  public double getRebbulkps_9_12_I() {
    return rebbulkps_9_12_I;
  }

  public double getRebbulkps_9_12_T() {
    return rebbulkps_9_12_T;
  }

  public double getRebbulkps_9_12_V() {
    return rebbulkps_9_12_V;
  }

  public double getRebbulkps_Brd_T() {
    return rebbulkps_Brd_T;
  }

  @Override
  public String toString() {
    return "Quadbox_REB_Bulk_PSTelemetry{" + "rebbulkps_0_2_I=" + rebbulkps_0_2_I +
        ", rebbulkps_0_2_T=" + rebbulkps_0_2_T +", rebbulkps_0_2_V=" + rebbulkps_0_2_V +
        ", rebbulkps_3_5_I=" + rebbulkps_3_5_I +", rebbulkps_3_5_T=" + rebbulkps_3_5_T +
        ", rebbulkps_3_5_V=" + rebbulkps_3_5_V +", rebbulkps_6_8_I=" + rebbulkps_6_8_I +
        ", rebbulkps_6_8_T=" + rebbulkps_6_8_T +", rebbulkps_6_8_V=" + rebbulkps_6_8_V +
        ", rebbulkps_9_12_I=" + rebbulkps_9_12_I +", rebbulkps_9_12_T=" + rebbulkps_9_12_T +
        ", rebbulkps_9_12_V=" + rebbulkps_9_12_V +", rebbulkps_Brd_T=" + rebbulkps_Brd_T +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private double rebbulkps_0_2_I;

    private double rebbulkps_0_2_T;

    private double rebbulkps_0_2_V;

    private double rebbulkps_3_5_I;

    private double rebbulkps_3_5_T;

    private double rebbulkps_3_5_V;

    private double rebbulkps_6_8_I;

    private double rebbulkps_6_8_T;

    private double rebbulkps_6_8_V;

    private double rebbulkps_9_12_I;

    private double rebbulkps_9_12_T;

    private double rebbulkps_9_12_V;

    private double rebbulkps_Brd_T;

    private Builder() {
    }

    public Builder rebbulkps_0_2_I(double rebbulkps_0_2_I) {
      this.rebbulkps_0_2_I = rebbulkps_0_2_I;
      return this;
    }

    public Builder rebbulkps_0_2_T(double rebbulkps_0_2_T) {
      this.rebbulkps_0_2_T = rebbulkps_0_2_T;
      return this;
    }

    public Builder rebbulkps_0_2_V(double rebbulkps_0_2_V) {
      this.rebbulkps_0_2_V = rebbulkps_0_2_V;
      return this;
    }

    public Builder rebbulkps_3_5_I(double rebbulkps_3_5_I) {
      this.rebbulkps_3_5_I = rebbulkps_3_5_I;
      return this;
    }

    public Builder rebbulkps_3_5_T(double rebbulkps_3_5_T) {
      this.rebbulkps_3_5_T = rebbulkps_3_5_T;
      return this;
    }

    public Builder rebbulkps_3_5_V(double rebbulkps_3_5_V) {
      this.rebbulkps_3_5_V = rebbulkps_3_5_V;
      return this;
    }

    public Builder rebbulkps_6_8_I(double rebbulkps_6_8_I) {
      this.rebbulkps_6_8_I = rebbulkps_6_8_I;
      return this;
    }

    public Builder rebbulkps_6_8_T(double rebbulkps_6_8_T) {
      this.rebbulkps_6_8_T = rebbulkps_6_8_T;
      return this;
    }

    public Builder rebbulkps_6_8_V(double rebbulkps_6_8_V) {
      this.rebbulkps_6_8_V = rebbulkps_6_8_V;
      return this;
    }

    public Builder rebbulkps_9_12_I(double rebbulkps_9_12_I) {
      this.rebbulkps_9_12_I = rebbulkps_9_12_I;
      return this;
    }

    public Builder rebbulkps_9_12_T(double rebbulkps_9_12_T) {
      this.rebbulkps_9_12_T = rebbulkps_9_12_T;
      return this;
    }

    public Builder rebbulkps_9_12_V(double rebbulkps_9_12_V) {
      this.rebbulkps_9_12_V = rebbulkps_9_12_V;
      return this;
    }

    public Builder rebbulkps_Brd_T(double rebbulkps_Brd_T) {
      this.rebbulkps_Brd_T = rebbulkps_Brd_T;
      return this;
    }

    public Quadbox_REB_Bulk_PSTelemetry build() {
      return new Quadbox_REB_Bulk_PSTelemetry(rebbulkps_0_2_I, rebbulkps_0_2_T, rebbulkps_0_2_V, rebbulkps_3_5_I, rebbulkps_3_5_T, rebbulkps_3_5_V, rebbulkps_6_8_I, rebbulkps_6_8_T, rebbulkps_6_8_V, rebbulkps_9_12_I, rebbulkps_9_12_T, rebbulkps_9_12_V, rebbulkps_Brd_T);
    }
  }
}
